Extensible models
=================

In AlekSIS you can use ``ExtensibleModels`` to add model fields to other
apps models.

If you want to make your apps models extensible, use the ``ExtensibleModel``
class as parent class of your models.

.. automodule:: aleksis.core.mixins
   :members:
